@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -183,8 +183,8 @@ gpm_button_grab_keystring (GpmButton   *button,
  **/
 static gboolean
 gpm_button_button_key (GpmButton   *button,
-			   const gchar *keystr,
-			   const gchar *hal_key)
+		       const gchar *keystr,
+		       const gchar *hal_key)
 {
 	char *key = NULL;
 	gboolean ret;
@@ -238,6 +238,8 @@ gpm_button_class_init (GpmButtonClass *klass)
 gboolean
 gpm_button_is_lid_closed (GpmButton *button)
 {
+	g_return_val_if_fail (button != NULL, FALSE);
+	g_return_val_if_fail (GPM_IS_BUTTON (button), FALSE);
 	return button->priv->lid_is_closed;
 }
 
@@ -272,7 +274,7 @@ emit_button_pressed (GpmButton *button,
 	if (strcmp (details, "") == 0) {
 		/* no details about the event, so we get more info
 		   for type 1 buttons */
-		gpm_hal_device_get_string (button->priv->hal, udi, "button.type", &type);
+		gpm_hal_device_get_string (button->priv->hal, udi, "button.type", &type, NULL);
 		/* hal may no longer be there */
 		g_return_if_fail (type != NULL);
 	} else {
@@ -284,7 +286,7 @@ emit_button_pressed (GpmButton *button,
 	state = TRUE;
 	/* we need to get the button state for lid buttons */
 	if (strcmp (type, "lid") == 0) {
-		gpm_hal_device_get_bool (button->priv->hal, udi, "button.state.value", &state);
+		gpm_hal_device_get_bool (button->priv->hal, udi, "button.state.value", &state, NULL);
 	}
 
 	/* abstact away that HAL has an extra parameter */
@@ -406,6 +408,8 @@ gpm_button_init (GpmButton *button)
 	gboolean have_xevents = FALSE;
 	int    i;
 	char **device_names = NULL;
+	gboolean ret;
+	GError *error;
 
 	button->priv = GPM_BUTTON_GET_PRIVATE (button);
 
@@ -444,22 +448,27 @@ gpm_button_init (GpmButton *button)
 	button->priv->hal = gpm_hal_new ();
 
 	/* devices of type button */
-	gpm_hal_device_find_capability (button->priv->hal, "button", &device_names);
-	if (! device_names) {
-		gpm_debug ("Couldn't obtain list of buttons");
+	error = NULL;
+	ret = gpm_hal_device_find_capability (button->priv->hal, "button", &device_names, &error);
+	if (ret == FALSE) {
+		gpm_warning ("Couldn't obtain list of buttons: %s", error->message);
+		g_error_free (error);
 		return;
 	}
-
-	for (i = 0; device_names[i]; i++) {
-		watch_add_button (button, device_names [i]);
+	if (device_names[0] != NULL) {
+		/* we have found buttons */
+		for (i = 0; device_names[i]; i++) {
+			watch_add_button (button, device_names[i]);
+		}
+		g_signal_connect (button->priv->hal, "property-modified",
+				  G_CALLBACK (hal_device_property_modified_cb), button);
+		g_signal_connect (button->priv->hal, "device-condition",
+				  G_CALLBACK (hal_device_condition_cb), button);
+	} else {
+		gpm_debug ("Couldn't obtain list of buttons");
 	}
 
 	gpm_hal_free_capability (button->priv->hal, device_names);
-
-	g_signal_connect (button->priv->hal, "property-modified",
-			  G_CALLBACK (hal_device_property_modified_cb), button);
-	g_signal_connect (button->priv->hal, "device-condition",
-			  G_CALLBACK (hal_device_condition_cb), button);
 }
 
 /**
